# coding: utf-8

"""
    RTU MIREA VUC

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.4.8
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Any, List, Optional
from pydantic import BaseModel, StrictStr
from pydantic import Field
from schedule_service_client.models.subject import Subject
from typing import Dict, Any
try:
    from typing import Self
except ImportError:
    from typing_extensions import Self

class WeekSchedule(BaseModel):
    """
    WeekSchedule
    """
    var_date: Optional[StrictStr] = Field(alias="date")
    datetime: Optional[StrictStr]
    subjects: List[Subject]
    coordinates: Optional[Any]
    __properties: ClassVar[List[str]] = ["date", "datetime", "subjects", "coordinates"]

    model_config = {
        "populate_by_name": True,
        "validate_assignment": True
    }


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of WeekSchedule from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        _dict = self.model_dump(
            by_alias=True,
            exclude={
            },
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in subjects (list)
        _items = []
        if self.subjects:
            for _item in self.subjects:
                if _item:
                    _items.append(_item.to_dict())
            _dict['subjects'] = _items
        # set to None if var_date (nullable) is None
        # and model_fields_set contains the field
        if self.var_date is None and "var_date" in self.model_fields_set:
            _dict['date'] = None

        # set to None if datetime (nullable) is None
        # and model_fields_set contains the field
        if self.datetime is None and "datetime" in self.model_fields_set:
            _dict['datetime'] = None

        # set to None if coordinates (nullable) is None
        # and model_fields_set contains the field
        if self.coordinates is None and "coordinates" in self.model_fields_set:
            _dict['coordinates'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> Self:
        """Create an instance of WeekSchedule from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "date": obj.get("date"),
            "datetime": obj.get("datetime"),
            "subjects": [Subject.from_dict(_item) for _item in obj.get("subjects")] if obj.get("subjects") is not None else None,
            "coordinates": obj.get("coordinates")
        })
        return _obj





# coding: utf-8

"""
    RTU MIREA VUC

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.4.8
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from schedule_service_client.api.healthcheck_api import HealthcheckApi  # noqa: E501


class TestHealthcheckApi(unittest.TestCase):
    """HealthcheckApi unit test stubs"""

    def setUp(self) -> None:
        self.api = HealthcheckApi()  # noqa: E501

    def tearDown(self) -> None:
        pass

    def test_health_health_get(self) -> None:
        """Test case for health_health_get

        Health  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    RTU MIREA VUC

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.4.8
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import List
from pydantic import BaseModel, StrictInt
from schedule_service_client.models.day import Day
from typing import Dict, Any
try:
    from typing import Self
except ImportError:
    from typing_extensions import Self

class WeekDate(BaseModel):
    """
    WeekDate
    """
    week: StrictInt
    days: List[Day]
    __properties: ClassVar[List[str]] = ["week", "days"]

    model_config = {
        "populate_by_name": True,
        "validate_assignment": True
    }


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of WeekDate from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        _dict = self.model_dump(
            by_alias=True,
            exclude={
            },
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in days (list)
        _items = []
        if self.days:
            for _item in self.days:
                if _item:
                    _items.append(_item.to_dict())
            _dict['days'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> Self:
        """Create an instance of WeekDate from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "week": obj.get("week"),
            "days": [Day.from_dict(_item) for _item in obj.get("days")] if obj.get("days") is not None else None
        })
        return _obj





# coding: utf-8

"""
    RTU MIREA VUC

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.4.8
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import List
from pydantic import BaseModel, StrictInt, StrictStr
from typing import Dict, Any
try:
    from typing import Self
except ImportError:
    from typing_extensions import Self

class Day(BaseModel):
    """
    Day
    """
    day: StrictStr
    platoons: List[StrictInt]
    __properties: ClassVar[List[str]] = ["day", "platoons"]

    model_config = {
        "populate_by_name": True,
        "validate_assignment": True
    }


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of Day from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        _dict = self.model_dump(
            by_alias=True,
            exclude={
            },
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> Self:
        """Create an instance of Day from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "day": obj.get("day"),
            "platoons": obj.get("platoons")
        })
        return _obj





# coding: utf-8

"""
    RTU MIREA VUC

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.4.8
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from schedule_service_client.models.schedule_result import ScheduleResult  # noqa: E501

class TestScheduleResult(unittest.TestCase):
    """ScheduleResult unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ScheduleResult:
        """Test ScheduleResult
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ScheduleResult`
        """
        model = ScheduleResult()  # noqa: E501
        if include_optional:
            return ScheduleResult(
                week = 56,
                schedule = [
                    schedule_service_client.models.week_schedule_result.WeekScheduleResult(
                        platoon = schedule_service_client.models.platoon.Platoon(
                            specialty_code = 56, 
                            platoon_number = 56, ), 
                        schedule = schedule_service_client.models.week_schedule.WeekSchedule(
                            date = '', 
                            datetime = '', 
                            subjects = [
                                schedule_service_client.models.subject.Subject(
                                    name = '', 
                                    auditory = '', 
                                    teacher = '', 
                                    lesson = schedule_service_client.models.lesson.Lesson(
                                        topic = 56, 
                                        lesson = 56, 
                                        type = '', ), )
                                ], 
                            coordinates = null, ), )
                    ]
            )
        else:
            return ScheduleResult(
                week = 56,
                schedule = [
                    schedule_service_client.models.week_schedule_result.WeekScheduleResult(
                        platoon = schedule_service_client.models.platoon.Platoon(
                            specialty_code = 56, 
                            platoon_number = 56, ), 
                        schedule = schedule_service_client.models.week_schedule.WeekSchedule(
                            date = '', 
                            datetime = '', 
                            subjects = [
                                schedule_service_client.models.subject.Subject(
                                    name = '', 
                                    auditory = '', 
                                    teacher = '', 
                                    lesson = schedule_service_client.models.lesson.Lesson(
                                        topic = 56, 
                                        lesson = 56, 
                                        type = '', ), )
                                ], 
                            coordinates = null, ), )
                    ],
        )
        """

    def testScheduleResult(self):
        """Test ScheduleResult"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# flake8: noqa

# import apis into api package
from schedule_service_client.api.healthcheck_api import HealthcheckApi
from schedule_service_client.api.schedule_api import ScheduleApi
from schedule_service_client.api.workbook_api import WorkbookApi




# coding: utf-8

"""
    RTU MIREA VUC

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.4.8
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from schedule_service_client.models.week_schedule_result import WeekScheduleResult  # noqa: E501

class TestWeekScheduleResult(unittest.TestCase):
    """WeekScheduleResult unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> WeekScheduleResult:
        """Test WeekScheduleResult
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `WeekScheduleResult`
        """
        model = WeekScheduleResult()  # noqa: E501
        if include_optional:
            return WeekScheduleResult(
                platoon = schedule_service_client.models.platoon.Platoon(
                    specialty_code = 56, 
                    platoon_number = 56, ),
                schedule = schedule_service_client.models.week_schedule.WeekSchedule(
                    date = '', 
                    datetime = '', 
                    subjects = [
                        schedule_service_client.models.subject.Subject(
                            name = '', 
                            auditory = '', 
                            teacher = '', 
                            lesson = schedule_service_client.models.lesson.Lesson(
                                topic = 56, 
                                lesson = 56, 
                                type = '', ), )
                        ], 
                    coordinates = null, )
            )
        else:
            return WeekScheduleResult(
                platoon = schedule_service_client.models.platoon.Platoon(
                    specialty_code = 56, 
                    platoon_number = 56, ),
                schedule = schedule_service_client.models.week_schedule.WeekSchedule(
                    date = '', 
                    datetime = '', 
                    subjects = [
                        schedule_service_client.models.subject.Subject(
                            name = '', 
                            auditory = '', 
                            teacher = '', 
                            lesson = schedule_service_client.models.lesson.Lesson(
                                topic = 56, 
                                lesson = 56, 
                                type = '', ), )
                        ], 
                    coordinates = null, ),
        )
        """

    def testWeekScheduleResult(self):
        """Test WeekScheduleResult"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    RTU MIREA VUC

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.4.8
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from schedule_service_client.api.schedule_api import ScheduleApi  # noqa: E501


class TestScheduleApi(unittest.TestCase):
    """ScheduleApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ScheduleApi()  # noqa: E501

    def tearDown(self) -> None:
        pass

    def test_get_days_week_api_v1_schedule_day_week_get(self) -> None:
        """Test case for get_days_week_api_v1_schedule_day_week_get

        Get Days Week  # noqa: E501
        """
        pass

    def test_get_platoons_api_v1_schedule_platoons_get(self) -> None:
        """Test case for get_platoons_api_v1_schedule_platoons_get

        Get Platoons  # noqa: E501
        """
        pass

    def test_get_schedule_api_v1_schedule_get(self) -> None:
        """Test case for get_schedule_api_v1_schedule_get

        Get Schedule  # noqa: E501
        """
        pass

    def test_get_week_schedule_api_v1_schedule_week_get(self) -> None:
        """Test case for get_week_schedule_api_v1_schedule_week_get

        Get Week Schedule  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    RTU MIREA VUC

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.4.8
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from schedule_service_client.api.workbook_api import WorkbookApi  # noqa: E501


class TestWorkbookApi(unittest.TestCase):
    """WorkbookApi unit test stubs"""

    def setUp(self) -> None:
        self.api = WorkbookApi()  # noqa: E501

    def tearDown(self) -> None:
        pass

    def test_get_course_workbook_api_v1_workbook_course_get(self) -> None:
        """Test case for get_course_workbook_api_v1_workbook_course_get

        Get Course Workbook  # noqa: E501
        """
        pass

    def test_get_course_workbook_relevance_api_v1_workbook_relevance_course_get(self) -> None:
        """Test case for get_course_workbook_relevance_api_v1_workbook_relevance_course_get

        Get Course Workbook Relevance  # noqa: E501
        """
        pass

    def test_get_workbooks_api_v1_workbook_get(self) -> None:
        """Test case for get_workbooks_api_v1_workbook_get

        Get Workbooks  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
